import * as React from 'react';
import { OutputDescriptor } from 'tsp-typescript-client/lib/models/output-descriptor';
import { ITspClient } from 'tsp-typescript-client/lib/protocol/tsp-client';
import { TimeGraphUnitController } from 'timeline-chart/lib/time-graph-unit-controller';
import { TimeRange } from 'traceviewer-base/lib/utils/time-range';
import { OutputComponentStyle } from './utils/output-component-style';
import { OutputStyleModel } from 'tsp-typescript-client/lib/models/styles';
import { TooltipComponent } from './tooltip-component';
import { TooltipXYComponent } from './tooltip-xy-component';
import { DropDownComponent, DropDownSubSection } from './drop-down-component';
export interface AbstractOutputProps {
    tspClient: ITspClient;
    tooltipComponent: TooltipComponent | null;
    tooltipXYComponent: TooltipXYComponent | null;
    traceId: string;
    traceName?: string;
    range: TimeRange;
    nbEvents: number;
    viewRange: TimeRange;
    selectionRange: TimeRange | undefined;
    resolution?: number;
    outputDescriptor: OutputDescriptor;
    markerCategories: string[] | undefined;
    markerSetId: string;
    style: OutputComponentStyle;
    outputWidth: number;
    backgroundTheme: string;
    onOutputRemove: (outputId: string) => void;
    unitController: TimeGraphUnitController;
    onSelectionRangeChange?: () => void;
    onViewRangeChange?: () => void;
    className?: string;
    onMouseUp?: VoidFunction;
    onMouseDown?: VoidFunction;
    onTouchStart?: VoidFunction;
    onTouchEnd?: VoidFunction;
    setChartOffset?: (chartOffset: number) => void;
    pinned?: boolean;
    persistChartState?: any;
    children?: string;
}
export interface AbstractOutputState {
    outputStatus: string;
    styleModel?: OutputStyleModel;
    dropDownOpen?: boolean;
}
export declare abstract class AbstractOutputComponent<P extends AbstractOutputProps, S extends AbstractOutputState> extends React.Component<P, S> {
    private readonly DEFAULT_HANDLE_WIDTH;
    protected mainOutputContainer: React.RefObject<HTMLDivElement>;
    protected dropDownMenuRef: React.RefObject<DropDownComponent>;
    private titleRef;
    private titleBarLabelRef;
    readonly PIN_VIEW_LABEL = "Pin View";
    readonly UNPIN_VIEW_LABEL = "Unpin View";
    readonly TOGGLE_COLUMN_LABEL = "Toggle Columns";
    private dropDownOptions;
    constructor(props: P);
    render(): JSX.Element;
    private renderTitleBar;
    private showViewOptionsCondition;
    protected toggleDropDown(): void;
    protected closeDropDown(): void;
    protected openDropDown(): void;
    private closeComponent;
    protected getHandleWidth(): number;
    getMainAreaWidth(): number;
    private renderMainOutputContainer;
    abstract setFocus(): void;
    abstract renderMainArea(): React.ReactNode;
    abstract resultsAreEmpty(): boolean;
    protected addPinViewOptions(arg?: () => unknown): void;
    protected addOptions(label: string, onClick?: (arg?: unknown) => void, arg?: unknown, condition?: () => boolean, subSection?: DropDownSubSection): void;
    protected pinView(payload?: any): void;
    protected unPinView(payload?: any): void;
    protected renderAnalysisFailed(): React.ReactElement;
    protected renderEmptyResults(): React.ReactElement;
    protected getOutputComponentDomId(): string;
    protected getOutputComponentName(): string;
    protected getTitleBarTooltip(): string;
}
//# sourceMappingURL=abstract-output-component.d.ts.map